pub fn combine_keys(keys: impl IntoIterator<Item = PublicKey>) -> PublicKeyExpand description
Aggregates the public keys into their aggregate public key.
Key order is not important as keys are sorted before aggregation.
pub fn combine_keys(keys: impl IntoIterator<Item = PublicKey>) -> PublicKeyAggregates the public keys into their aggregate public key.
Key order is not important as keys are sorted before aggregation.